autowisp.database.initialize_database module — AutoWISP documentation

# autowisp.database.initialize_database module

## Class Inheritance Diagram

Create all datbase tables and define default configuration.

class autowisp.database.initialize_database.StepCreator

  Bases: `object`

  Add steps to the database one by one.

  __call__(step_name, db_session)

    Add a step with the given name to the database.

  __init__()

    Get ready to add steps to the database.

autowisp.database.initialize_database._overwrite_defaults(new_defaults)

  Overwrite default values from what is defined in the steps.

autowisp.database.initialize_database.add_default_hdf5_structures(data_reduction=True, light_curve=True)

  Add a default HDF5 structure to the database.

  Parameters:

    - data_reduction (bool) – Should the structure of data reduction files be initialized?

    - light_curve (bool) – Should the structure of light curve files be initialized?

autowisp.database.initialize_database.add_master_dependencies(db_session)

  Fill the master_types table.

autowisp.database.initialize_database.drop_tables_matching(pattern)

  Drop tables with names matching a pre-compiled regular expression.

autowisp.database.initialize_database.get_command_line_parser()

  Create a parser with all required command line arguments.

autowisp.database.initialize_database.init_processing()

  Initialize the tables controlling how processing is to be done.

autowisp.database.initialize_database.initialize_database(cmdline_args, overwrite_defaults=None)

  Initialize the database as specified on the command line.